{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<font color='red' size=5><b>Intital Testing</b></font>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "import tensorflow as tf"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### In this notebook I followed the example in:\n",
    "\n",
    "https://www.nengo.ai/nengo-dl/examples/lmu.html"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "%matplotlib inline\n",
    "\n",
    "from urllib.request import urlretrieve\n",
    "\n",
    "import matplotlib.pyplot as plt\n",
    "import nengo\n",
    "from nengo.utils.filter_design import cont2discrete\n",
    "import numpy as np\n",
    "import tensorflow as tf\n",
    "\n",
    "import nengo_dl"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "class LMUCell(nengo.Network):\n",
    "    def __init__(self, units, order, theta, input_d, **kwargs):\n",
    "        super().__init__(**kwargs)\n",
    "\n",
    "        # compute the A and B matrices according to the LMU's mathematical derivation\n",
    "        # (see the paper for details)\n",
    "        Q = np.arange(order, dtype=np.float64)\n",
    "        R = (2 * Q + 1)[:, None] / theta\n",
    "        j, i = np.meshgrid(Q, Q)\n",
    "\n",
    "        A = np.where(i < j, -1, (-1.0) ** (i - j + 1)) * R\n",
    "        B = (-1.0) ** Q[:, None] * R\n",
    "        C = np.ones((1, order))\n",
    "        D = np.zeros((1,))\n",
    "\n",
    "        A, B, _, _, _ = cont2discrete((A, B, C, D), dt=1.0, method=\"zoh\")\n",
    "\n",
    "        with self:\n",
    "            nengo_dl.configure_settings(trainable=None)\n",
    "\n",
    "            # create objects corresponding to the x/u/m/h variables in the above diagram\n",
    "            self.x = nengo.Node(size_in=input_d)\n",
    "            self.u = nengo.Node(size_in=1)\n",
    "            self.m = nengo.Node(size_in=order)\n",
    "            self.h = nengo_dl.TensorNode(tf.nn.tanh, shape_in=(units,), pass_time=False)\n",
    "\n",
    "            # compute u_t from the above diagram. we have removed e_h and e_m as they\n",
    "            # are not needed in this task.\n",
    "            nengo.Connection(\n",
    "                self.x, self.u, transform=np.ones((1, input_d)), synapse=None\n",
    "            )\n",
    "\n",
    "            # compute m_t\n",
    "            # in this implementation we'll make A and B non-trainable, but they\n",
    "            # could also be optimized in the same way as the other parameters.\n",
    "            # note that setting synapse=0 (versus synapse=None) adds a one-timestep\n",
    "            # delay, so we can think of any connections with synapse=0 as representing\n",
    "            # value_{t-1}.\n",
    "            conn_A = nengo.Connection(self.m, self.m, transform=A, synapse=0)\n",
    "            self.config[conn_A].trainable = False\n",
    "            conn_B = nengo.Connection(self.u, self.m, transform=B, synapse=None)\n",
    "            self.config[conn_B].trainable = False\n",
    "\n",
    "            # compute h_t\n",
    "            nengo.Connection(\n",
    "                self.x, self.h, transform=nengo_dl.dists.Glorot(), synapse=None\n",
    "            )\n",
    "            nengo.Connection(\n",
    "                self.h, self.h, transform=nengo_dl.dists.Glorot(), synapse=0\n",
    "            )\n",
    "            nengo.Connection(\n",
    "                self.m,\n",
    "                self.h,\n",
    "                transform=nengo_dl.dists.Glorot(),\n",
    "                synapse=None,\n",
    "            )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Example With Dummy data from:\n",
    "https://machinelearningmastery.com/how-to-develop-convolutional-neural-network-models-for-time-series-forecasting/\n",
    " \n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 145,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "(7, 3, 2)\n",
      "(1, 3, 2)\n",
      "Build finished in 0:00:00                                                      \n",
      "Optimization finished in 0:00:00                                               \n",
      "Construction finished in 0:00:00                                               \n",
      "Epoch 1/1000\n",
      "7/7 [==============================] - 2s 5ms/step - loss: 16762.8945 - probe_loss: 16762.8945\n",
      "Epoch 2/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 15475.7334 - probe_loss: 15475.7334\n",
      "Epoch 3/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 14568.8545 - probe_loss: 14568.8545\n",
      "Epoch 4/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 13965.1299 - probe_loss: 13965.1299\n",
      "Epoch 5/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 13417.4346 - probe_loss: 13417.4346\n",
      "Epoch 6/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 12868.0205 - probe_loss: 12868.0205\n",
      "Epoch 7/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 12383.3760 - probe_loss: 12383.3760\n",
      "Epoch 8/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 11938.5391 - probe_loss: 11938.5391\n",
      "Epoch 9/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 11518.8906 - probe_loss: 11518.8906\n",
      "Epoch 10/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 11173.7158 - probe_loss: 11173.7158\n",
      "Epoch 11/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 10777.2373 - probe_loss: 10777.2373\n",
      "Epoch 12/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 10470.6592 - probe_loss: 10470.6592\n",
      "Epoch 13/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 10141.0000 - probe_loss: 10141.0000\n",
      "Epoch 14/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 9870.2891 - probe_loss: 9870.2891\n",
      "Epoch 15/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 9572.6885 - probe_loss: 9572.6885\n",
      "Epoch 16/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 9260.8096 - probe_loss: 9260.8096\n",
      "Epoch 17/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 9001.6992 - probe_loss: 9001.6992\n",
      "Epoch 18/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 8745.5596 - probe_loss: 8745.5596\n",
      "Epoch 19/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 8470.1494 - probe_loss: 8470.1494\n",
      "Epoch 20/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 8242.0264 - probe_loss: 8242.0264\n",
      "Epoch 21/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 7982.9810 - probe_loss: 7982.9810\n",
      "Epoch 22/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 7764.2188 - probe_loss: 7764.2188\n",
      "Epoch 23/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 7534.1753 - probe_loss: 7534.1753\n",
      "Epoch 24/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 7308.4722 - probe_loss: 7308.4722\n",
      "Epoch 25/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 7113.6279 - probe_loss: 7113.6279\n",
      "Epoch 26/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 6904.5898 - probe_loss: 6904.5898\n",
      "Epoch 27/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 6728.5903 - probe_loss: 6728.5903\n",
      "Epoch 28/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 6518.3823 - probe_loss: 6518.3823\n",
      "Epoch 29/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 6331.8921 - probe_loss: 6331.8921\n",
      "Epoch 30/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 6156.3823 - probe_loss: 6156.3823\n",
      "Epoch 31/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5978.4810 - probe_loss: 5978.4810\n",
      "Epoch 32/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 5801.0708 - probe_loss: 5801.0708\n",
      "Epoch 33/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5664.1567 - probe_loss: 5664.1567\n",
      "Epoch 34/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5501.5298 - probe_loss: 5501.5298\n",
      "Epoch 35/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5342.3325 - probe_loss: 5342.3325\n",
      "Epoch 36/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5196.3315 - probe_loss: 5196.3315\n",
      "Epoch 37/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 5048.2119 - probe_loss: 5048.2119\n",
      "Epoch 38/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 4909.4097 - probe_loss: 4909.4097\n",
      "Epoch 39/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 4771.3477 - probe_loss: 4771.3477\n",
      "Epoch 40/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 4626.9370 - probe_loss: 4626.9370\n",
      "Epoch 41/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 4523.8042 - probe_loss: 4523.8042\n",
      "Epoch 42/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 4396.5757 - probe_loss: 4396.5757\n",
      "Epoch 43/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 5215.7026 - probe_loss: 5215.70 - 0s 4ms/step - loss: 4277.2725 - probe_loss: 4277.2725\n",
      "Epoch 44/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 4174.1577 - probe_loss: 4174.1577\n",
      "Epoch 45/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 4075.4578 - probe_loss: 4075.4578\n",
      "Epoch 46/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 3971.7947 - probe_loss: 3971.7947\n",
      "Epoch 47/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3848.0730 - probe_loss: 3848.0730\n",
      "Epoch 48/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3762.6326 - probe_loss: 3762.6326\n",
      "Epoch 49/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 3681.0254 - probe_loss: 3681.0254\n",
      "Epoch 50/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3583.7449 - probe_loss: 3583.7449\n",
      "Epoch 51/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3515.7578 - probe_loss: 3515.7578\n",
      "Epoch 52/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3420.3594 - probe_loss: 3420.3594\n",
      "Epoch 53/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 3340.8811 - probe_loss: 3340.8811\n",
      "Epoch 54/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3272.4460 - probe_loss: 3272.4460\n",
      "Epoch 55/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 3202.2969 - probe_loss: 3202.2969\n",
      "Epoch 56/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 3114.6809 - probe_loss: 3114.6809\n",
      "Epoch 57/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 3047.2336 - probe_loss: 3047.2336\n",
      "Epoch 58/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2998.2817 - probe_loss: 2998.2817\n",
      "Epoch 59/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2928.6160 - probe_loss: 2928.6160\n",
      "Epoch 60/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2864.0347 - probe_loss: 2864.0347\n",
      "Epoch 61/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2819.1316 - probe_loss: 2819.1316\n",
      "Epoch 62/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2745.9531 - probe_loss: 2745.9531\n",
      "Epoch 63/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2705.2439 - probe_loss: 2705.2439\n",
      "Epoch 64/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2647.3381 - probe_loss: 2647.3381\n",
      "Epoch 65/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2659.9453 - probe_loss: 2659.9453\n",
      "Epoch 66/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2603.5359 - probe_loss: 2603.5359\n",
      "Epoch 67/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2572.3523 - probe_loss: 2572.3523\n",
      "Epoch 68/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2488.5540 - probe_loss: 2488.5540\n",
      "Epoch 69/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2463.1343 - probe_loss: 2463.1343\n",
      "Epoch 70/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 2386.5525 - probe_loss: 2386.5525\n",
      "Epoch 71/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2342.5044 - probe_loss: 2342.5044\n",
      "Epoch 72/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2285.1956 - probe_loss: 2285.1956\n",
      "Epoch 73/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2304.8569 - probe_loss: 2304.8569\n",
      "Epoch 74/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2254.1997 - probe_loss: 2254.1997\n",
      "Epoch 75/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 2206.0376 - probe_loss: 2206.0376\n",
      "Epoch 76/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2155.0085 - probe_loss: 2155.0085\n",
      "Epoch 77/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2097.4050 - probe_loss: 2097.4050\n",
      "Epoch 78/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2054.1052 - probe_loss: 2054.1052\n",
      "Epoch 79/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 2008.5793 - probe_loss: 2008.5793\n",
      "Epoch 80/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1970.8235 - probe_loss: 1970.8235\n",
      "Epoch 81/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1917.7266 - probe_loss: 1917.7266\n",
      "Epoch 82/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1890.6888 - probe_loss: 1890.6888\n",
      "Epoch 83/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1843.4164 - probe_loss: 1843.4164\n",
      "Epoch 84/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1805.1562 - probe_loss: 1805.1562\n",
      "Epoch 85/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1778.3630 - probe_loss: 1778.3630\n",
      "Epoch 86/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1744.1633 - probe_loss: 1744.1633\n",
      "Epoch 87/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1702.7023 - probe_loss: 1702.7023\n",
      "Epoch 88/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1689.0791 - probe_loss: 1689.0791\n",
      "Epoch 89/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1662.1749 - probe_loss: 1662.1749\n",
      "Epoch 90/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1629.8103 - probe_loss: 1629.8103\n",
      "Epoch 91/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1632.9729 - probe_loss: 1632.9729\n",
      "Epoch 92/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1582.6576 - probe_loss: 1582.6576\n",
      "Epoch 93/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1561.5814 - probe_loss: 1561.5814\n",
      "Epoch 94/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1548.0511 - probe_loss: 1548.0511\n",
      "Epoch 95/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1537.3888 - probe_loss: 1537.3888\n",
      "Epoch 96/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1488.5754 - probe_loss: 1488.5754\n",
      "Epoch 97/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1467.5978 - probe_loss: 1467.5978\n",
      "Epoch 98/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1476.3438 - probe_loss: 1476.3438\n",
      "Epoch 99/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1438.9186 - probe_loss: 1438.9186\n",
      "Epoch 100/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1419.1224 - probe_loss: 1419.1224\n",
      "Epoch 101/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1400.5769 - probe_loss: 1400.5769\n",
      "Epoch 102/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1385.9532 - probe_loss: 1385.9532\n",
      "Epoch 103/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1359.0588 - probe_loss: 1359.0588\n",
      "Epoch 104/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1345.8044 - probe_loss: 1345.8044\n",
      "Epoch 105/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1319.1483 - probe_loss: 1319.1483\n",
      "Epoch 106/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1335.7615 - probe_loss: 1335.7615\n",
      "Epoch 107/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1310.0266 - probe_loss: 1310.0266\n",
      "Epoch 108/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1286.2576 - probe_loss: 1286.2576\n",
      "Epoch 109/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1266.5027 - probe_loss: 1266.5027\n",
      "Epoch 110/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1311.0950 - probe_loss: 1311.0950\n",
      "Epoch 111/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1271.9840 - probe_loss: 1271.9840\n",
      "Epoch 112/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1252.9441 - probe_loss: 1252.9441\n",
      "Epoch 113/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1239.1989 - probe_loss: 1239.1989\n",
      "Epoch 114/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1268.5782 - probe_loss: 1268.5782\n",
      "Epoch 115/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1257.0969 - probe_loss: 1257.0969\n",
      "Epoch 116/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1245.9928 - probe_loss: 1245.9928\n",
      "Epoch 117/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1219.4910 - probe_loss: 1219.4910\n",
      "Epoch 118/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1200.0137 - probe_loss: 1200.0137\n",
      "Epoch 119/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1182.9454 - probe_loss: 1182.9454\n",
      "Epoch 120/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1164.9519 - probe_loss: 1164.9519\n",
      "Epoch 121/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1141.6375 - probe_loss: 1141.6375\n",
      "Epoch 122/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1128.7709 - probe_loss: 1128.7709\n",
      "Epoch 123/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1115.0023 - probe_loss: 1115.0023\n",
      "Epoch 124/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1131.4150 - probe_loss: 1131.4150\n",
      "Epoch 125/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1108.0999 - probe_loss: 1108.0999\n",
      "Epoch 126/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1104.1613 - probe_loss: 1104.1613\n",
      "Epoch 127/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1076.8035 - probe_loss: 1076.8035\n",
      "Epoch 128/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1131.2797 - probe_loss: 1131.2797\n",
      "Epoch 129/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1112.1764 - probe_loss: 1112.1764\n",
      "Epoch 130/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 1084.8782 - probe_loss: 1084.8782\n",
      "Epoch 131/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1077.4507 - probe_loss: 1077.4507\n",
      "Epoch 132/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1074.0031 - probe_loss: 1074.0031\n",
      "Epoch 133/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1057.7288 - probe_loss: 1057.7288\n",
      "Epoch 134/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1042.7632 - probe_loss: 1042.7632\n",
      "Epoch 135/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1033.7059 - probe_loss: 1033.7059\n",
      "Epoch 136/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1013.3365 - probe_loss: 1013.3365\n",
      "Epoch 137/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 1000.7919 - probe_loss: 1000.7919\n",
      "Epoch 138/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 997.9874 - probe_loss: 997.9874\n",
      "Epoch 139/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 975.0113 - probe_loss: 975.0113\n",
      "Epoch 140/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 981.9879 - probe_loss: 981.9879\n",
      "Epoch 141/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 996.6534 - probe_loss: 996.6534\n",
      "Epoch 142/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 1001.1575 - probe_loss: 1001.1575\n",
      "Epoch 143/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 965.1767 - probe_loss: 965.1767\n",
      "Epoch 144/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 954.7946 - probe_loss: 954.7946\n",
      "Epoch 145/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 947.9635 - probe_loss: 947.9635\n",
      "Epoch 146/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 924.2274 - probe_loss: 924.2274\n",
      "Epoch 147/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 919.5159 - probe_loss: 919.5159\n",
      "Epoch 148/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 900.5828 - probe_loss: 900.5828\n",
      "Epoch 149/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 909.1285 - probe_loss: 909.1285\n",
      "Epoch 150/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 901.1554 - probe_loss: 901.1554\n",
      "Epoch 151/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 895.0917 - probe_loss: 895.0917\n",
      "Epoch 152/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 880.2527 - probe_loss: 880.2527\n",
      "Epoch 153/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 867.2953 - probe_loss: 867.2953\n",
      "Epoch 154/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 872.1181 - probe_loss: 872.1181\n",
      "Epoch 155/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 884.0977 - probe_loss: 884.0977\n",
      "Epoch 156/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 873.1700 - probe_loss: 873.1700\n",
      "Epoch 157/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 872.5552 - probe_loss: 872.5552\n",
      "Epoch 158/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 861.8789 - probe_loss: 861.8789\n",
      "Epoch 159/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 858.2184 - probe_loss: 858.2184\n",
      "Epoch 160/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 848.2744 - probe_loss: 848.2744\n",
      "Epoch 161/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 843.9650 - probe_loss: 843.9650\n",
      "Epoch 162/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 833.1512 - probe_loss: 833.1512\n",
      "Epoch 163/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 847.0938 - probe_loss: 847.0938\n",
      "Epoch 164/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 851.7681 - probe_loss: 851.7681\n",
      "Epoch 165/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 828.8336 - probe_loss: 828.8336\n",
      "Epoch 166/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 828.9282 - probe_loss: 828.9282\n",
      "Epoch 167/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 816.9165 - probe_loss: 816.9165\n",
      "Epoch 168/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 808.5944 - probe_loss: 808.5944\n",
      "Epoch 169/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 806.0648 - probe_loss: 806.0648\n",
      "Epoch 170/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 791.2359 - probe_loss: 791.2359\n",
      "Epoch 171/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 646.0287 - probe_loss: 646.02 - 0s 4ms/step - loss: 807.3779 - probe_loss: 807.3779\n",
      "Epoch 172/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 797.2995 - probe_loss: 797.2995\n",
      "Epoch 173/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 801.5997 - probe_loss: 801.5997\n",
      "Epoch 174/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 793.2101 - probe_loss: 793.2101\n",
      "Epoch 175/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 800.4252 - probe_loss: 800.4252\n",
      "Epoch 176/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 793.0599 - probe_loss: 793.0599\n",
      "Epoch 177/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 778.8588 - probe_loss: 778.8588\n",
      "Epoch 178/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 777.8677 - probe_loss: 777.8677\n",
      "Epoch 179/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 778.5108 - probe_loss: 778.5108\n",
      "Epoch 180/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 768.4720 - probe_loss: 768.4720\n",
      "Epoch 181/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 775.1566 - probe_loss: 775.1566\n",
      "Epoch 182/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 771.2303 - probe_loss: 771.2303\n",
      "Epoch 183/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 779.1576 - probe_loss: 779.1576\n",
      "Epoch 184/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 769.6291 - probe_loss: 769.6291\n",
      "Epoch 185/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 765.3828 - probe_loss: 765.3828\n",
      "Epoch 186/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 754.2556 - probe_loss: 754.2556\n",
      "Epoch 187/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 750.1973 - probe_loss: 750.1973\n",
      "Epoch 188/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 743.5026 - probe_loss: 743.5026\n",
      "Epoch 189/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 736.9671 - probe_loss: 736.9671\n",
      "Epoch 190/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 728.1278 - probe_loss: 728.1278\n",
      "Epoch 191/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 720.1298 - probe_loss: 720.1298\n",
      "Epoch 192/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 718.7241 - probe_loss: 718.7241\n",
      "Epoch 193/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 712.2932 - probe_loss: 712.2932\n",
      "Epoch 194/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 710.8453 - probe_loss: 710.8453\n",
      "Epoch 195/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 706.2584 - probe_loss: 706.2584\n",
      "Epoch 196/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 705.2986 - probe_loss: 705.2986\n",
      "Epoch 197/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 760.2108 - probe_loss: 760.2108\n",
      "Epoch 198/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 781.4413 - probe_loss: 781.4413\n",
      "Epoch 199/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 738.4077 - probe_loss: 738.4077\n",
      "Epoch 200/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 730.4189 - probe_loss: 730.4189\n",
      "Epoch 201/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 720.5820 - probe_loss: 720.5820\n",
      "Epoch 202/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 716.0391 - probe_loss: 716.0391\n",
      "Epoch 203/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 707.1235 - probe_loss: 707.1235\n",
      "Epoch 204/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 701.4655 - probe_loss: 701.4655\n",
      "Epoch 205/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 709.8775 - probe_loss: 709.8775\n",
      "Epoch 206/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 709.0107 - probe_loss: 709.0107\n",
      "Epoch 207/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 720.3560 - probe_loss: 720.3560\n",
      "Epoch 208/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 712.4666 - probe_loss: 712.4666\n",
      "Epoch 209/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 719.7742 - probe_loss: 719.7742\n",
      "Epoch 210/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 722.7827 - probe_loss: 722.7827\n",
      "Epoch 211/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 714.2665 - probe_loss: 714.2665\n",
      "Epoch 212/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 701.7503 - probe_loss: 701.7503\n",
      "Epoch 213/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 699.2943 - probe_loss: 699.2943\n",
      "Epoch 214/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 692.8231 - probe_loss: 692.8231\n",
      "Epoch 215/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 714.4207 - probe_loss: 714.4207\n",
      "Epoch 216/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 697.8691 - probe_loss: 697.8691\n",
      "Epoch 217/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 711.9584 - probe_loss: 711.9584\n",
      "Epoch 218/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 720.1324 - probe_loss: 720.1324\n",
      "Epoch 219/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 712.9911 - probe_loss: 712.9911\n",
      "Epoch 220/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 713.1945 - probe_loss: 713.1945\n",
      "Epoch 221/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 712.9984 - probe_loss: 712.9984\n",
      "Epoch 222/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 703.0719 - probe_loss: 703.0719\n",
      "Epoch 223/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 700.2482 - probe_loss: 700.2482\n",
      "Epoch 224/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 690.1035 - probe_loss: 690.1035\n",
      "Epoch 225/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 678.4933 - probe_loss: 678.4933\n",
      "Epoch 226/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 701.6556 - probe_loss: 701.6556\n",
      "Epoch 227/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 690.8304 - probe_loss: 690.8304\n",
      "Epoch 228/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 683.4977 - probe_loss: 683.4977\n",
      "Epoch 229/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 700.6670 - probe_loss: 700.6670\n",
      "Epoch 230/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 699.5752 - probe_loss: 699.5752\n",
      "Epoch 231/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 689.5378 - probe_loss: 689.5378\n",
      "Epoch 232/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 676.7918 - probe_loss: 676.7918\n",
      "Epoch 233/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 674.0820 - probe_loss: 674.0820\n",
      "Epoch 234/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 659.9477 - probe_loss: 659.9477\n",
      "Epoch 235/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 661.2068 - probe_loss: 661.2068\n",
      "Epoch 236/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 654.1312 - probe_loss: 654.1312\n",
      "Epoch 237/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 651.8554 - probe_loss: 651.8554\n",
      "Epoch 238/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 648.9053 - probe_loss: 648.9053\n",
      "Epoch 239/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 648.7453 - probe_loss: 648.7453\n",
      "Epoch 240/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 646.8402 - probe_loss: 646.8402\n",
      "Epoch 241/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 642.0332 - probe_loss: 642.0332\n",
      "Epoch 242/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 657.8353 - probe_loss: 657.8353\n",
      "Epoch 243/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 641.5695 - probe_loss: 641.5695\n",
      "Epoch 244/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 645.8586 - probe_loss: 645.8586\n",
      "Epoch 245/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 663.5762 - probe_loss: 663.5762\n",
      "Epoch 246/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 655.4168 - probe_loss: 655.4168\n",
      "Epoch 247/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 657.9925 - probe_loss: 657.9925\n",
      "Epoch 248/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 657.9276 - probe_loss: 657.9276\n",
      "Epoch 249/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 657.4769 - probe_loss: 657.4769\n",
      "Epoch 250/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 674.3166 - probe_loss: 674.3166\n",
      "Epoch 251/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 653.9293 - probe_loss: 653.9293\n",
      "Epoch 252/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 644.1827 - probe_loss: 644.1827\n",
      "Epoch 253/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 640.3470 - probe_loss: 640.3470\n",
      "Epoch 254/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 651.4351 - probe_loss: 651.4351\n",
      "Epoch 255/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 646.3441 - probe_loss: 646.3441\n",
      "Epoch 256/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 643.2671 - probe_loss: 643.2671\n",
      "Epoch 257/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 635.9266 - probe_loss: 635.9266\n",
      "Epoch 258/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 647.0368 - probe_loss: 647.0368\n",
      "Epoch 259/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 662.8100 - probe_loss: 662.8100\n",
      "Epoch 260/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 653.9182 - probe_loss: 653.9182\n",
      "Epoch 261/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 703.0300 - probe_loss: 703.0300\n",
      "Epoch 262/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 697.2628 - probe_loss: 697.2628\n",
      "Epoch 263/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 692.9066 - probe_loss: 692.9066\n",
      "Epoch 264/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 684.0533 - probe_loss: 684.0533\n",
      "Epoch 265/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 680.0338 - probe_loss: 680.0338\n",
      "Epoch 266/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 667.3585 - probe_loss: 667.3585\n",
      "Epoch 267/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 662.4141 - probe_loss: 662.4141\n",
      "Epoch 268/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 667.6629 - probe_loss: 667.6629\n",
      "Epoch 269/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 670.2100 - probe_loss: 670.2100\n",
      "Epoch 270/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 671.4313 - probe_loss: 671.4313\n",
      "Epoch 271/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 668.7111 - probe_loss: 668.7111\n",
      "Epoch 272/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 663.4824 - probe_loss: 663.4824\n",
      "Epoch 273/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 654.1976 - probe_loss: 654.1976\n",
      "Epoch 274/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 651.0292 - probe_loss: 651.0292\n",
      "Epoch 275/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 644.3038 - probe_loss: 644.3038\n",
      "Epoch 276/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 642.4359 - probe_loss: 642.4359\n",
      "Epoch 277/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 633.9662 - probe_loss: 633.9662\n",
      "Epoch 278/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 644.5616 - probe_loss: 644.5616\n",
      "Epoch 279/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 640.3156 - probe_loss: 640.3156\n",
      "Epoch 280/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 640.2426 - probe_loss: 640.2426\n",
      "Epoch 281/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 722.8573 - probe_loss: 722.8573\n",
      "Epoch 282/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 698.3704 - probe_loss: 698.3704\n",
      "Epoch 283/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 690.0186 - probe_loss: 690.0186\n",
      "Epoch 284/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 685.5123 - probe_loss: 685.5123\n",
      "Epoch 285/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 679.5793 - probe_loss: 679.5793\n",
      "Epoch 286/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 675.5894 - probe_loss: 675.5894\n",
      "Epoch 287/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 663.3990 - probe_loss: 663.3990\n",
      "Epoch 288/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 657.3750 - probe_loss: 657.3750\n",
      "Epoch 289/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 653.0211 - probe_loss: 653.0211\n",
      "Epoch 290/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 647.6451 - probe_loss: 647.6451\n",
      "Epoch 291/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 643.7095 - probe_loss: 643.7095\n",
      "Epoch 292/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 642.0785 - probe_loss: 642.0785\n",
      "Epoch 293/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 638.6466 - probe_loss: 638.6466\n",
      "Epoch 294/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 637.6262 - probe_loss: 637.6262\n",
      "Epoch 295/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 635.2985 - probe_loss: 635.2985\n",
      "Epoch 296/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 631.9528 - probe_loss: 631.9528\n",
      "Epoch 297/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 620.6102 - probe_loss: 620.6102\n",
      "Epoch 298/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 624.0926 - probe_loss: 624.0926\n",
      "Epoch 299/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 631.0897 - probe_loss: 631.0897\n",
      "Epoch 300/1000\n",
      "7/7 [==============================] - 0s 19ms/step - loss: 621.0507 - probe_loss: 621.0507\n",
      "Epoch 301/1000\n",
      "7/7 [==============================] - 0s 41ms/step - loss: 644.2463 - probe_loss: 644.2463\n",
      "Epoch 302/1000\n",
      "7/7 [==============================] - 0s 61ms/step - loss: 659.7306 - probe_loss: 659.7306 0s - loss: 320.1702 - probe_loss: \n",
      "Epoch 303/1000\n",
      "7/7 [==============================] - 0s 49ms/step - loss: 636.3622 - probe_loss: 636.3622\n",
      "Epoch 304/1000\n",
      "7/7 [==============================] - 0s 53ms/step - loss: 635.1236 - probe_loss: 635.1236\n",
      "Epoch 305/1000\n",
      "7/7 [==============================] - 0s 62ms/step - loss: 622.2628 - probe_loss: 622.2628\n",
      "Epoch 306/1000\n",
      "7/7 [==============================] - 0s 44ms/step - loss: 616.5012 - probe_loss: 616.5012\n",
      "Epoch 307/1000\n",
      "7/7 [==============================] - 0s 44ms/step - loss: 610.2796 - probe_loss: 610.2796\n",
      "Epoch 308/1000\n",
      "7/7 [==============================] - 0s 42ms/step - loss: 609.4984 - probe_loss: 609.4984\n",
      "Epoch 309/1000\n",
      "7/7 [==============================] - 0s 17ms/step - loss: 606.1567 - probe_loss: 606.1567\n",
      "Epoch 310/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 604.9999 - probe_loss: 604.9999\n",
      "Epoch 311/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 604.4486 - probe_loss: 604.4486\n",
      "Epoch 312/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 603.2114 - probe_loss: 603.2114\n",
      "Epoch 313/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 592.0097 - probe_loss: 592.0097\n",
      "Epoch 314/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 594.3101 - probe_loss: 594.3101\n",
      "Epoch 315/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 588.3255 - probe_loss: 588.3255\n",
      "Epoch 316/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 589.6325 - probe_loss: 589.6325\n",
      "Epoch 317/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 593.5518 - probe_loss: 593.5518\n",
      "Epoch 318/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 597.7363 - probe_loss: 597.7363\n",
      "Epoch 319/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 618.3452 - probe_loss: 618.3452\n",
      "Epoch 320/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 606.5980 - probe_loss: 606.5980\n",
      "Epoch 321/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 612.8146 - probe_loss: 612.8146\n",
      "Epoch 322/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 602.7880 - probe_loss: 602.7880\n",
      "Epoch 323/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 596.5211 - probe_loss: 596.5211\n",
      "Epoch 324/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 595.6360 - probe_loss: 595.6360\n",
      "Epoch 325/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 598.3863 - probe_loss: 598.3863\n",
      "Epoch 326/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 596.0023 - probe_loss: 596.0023\n",
      "Epoch 327/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 610.9028 - probe_loss: 610.9028\n",
      "Epoch 328/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 622.2230 - probe_loss: 622.2230\n",
      "Epoch 329/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 625.8151 - probe_loss: 625.8151\n",
      "Epoch 330/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 612.0036 - probe_loss: 612.0036\n",
      "Epoch 331/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 608.7068 - probe_loss: 608.7068\n",
      "Epoch 332/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 607.8336 - probe_loss: 607.8336\n",
      "Epoch 333/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 620.3095 - probe_loss: 620.3095\n",
      "Epoch 334/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 648.2298 - probe_loss: 648.2298\n",
      "Epoch 335/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 611.7455 - probe_loss: 611.7455\n",
      "Epoch 336/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 621.2136 - probe_loss: 621.2136\n",
      "Epoch 337/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 604.2618 - probe_loss: 604.2618\n",
      "Epoch 338/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 603.4516 - probe_loss: 603.4516\n",
      "Epoch 339/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 598.4001 - probe_loss: 598.4001\n",
      "Epoch 340/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 590.2432 - probe_loss: 590.2432\n",
      "Epoch 341/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 605.7866 - probe_loss: 605.7866\n",
      "Epoch 342/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 605.3257 - probe_loss: 605.3257\n",
      "Epoch 343/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 598.6873 - probe_loss: 598.6873\n",
      "Epoch 344/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 593.5696 - probe_loss: 593.5696\n",
      "Epoch 345/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 589.7250 - probe_loss: 589.7250\n",
      "Epoch 346/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 586.8915 - probe_loss: 586.8915\n",
      "Epoch 347/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 577.2193 - probe_loss: 577.2193\n",
      "Epoch 348/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 597.5163 - probe_loss: 597.5163\n",
      "Epoch 349/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 591.2039 - probe_loss: 591.2039\n",
      "Epoch 350/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 611.4745 - probe_loss: 611.4745\n",
      "Epoch 351/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 603.0130 - probe_loss: 603.0130\n",
      "Epoch 352/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 600.0761 - probe_loss: 600.0761\n",
      "Epoch 353/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 605.8295 - probe_loss: 605.8295\n",
      "Epoch 354/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 593.8834 - probe_loss: 593.8834\n",
      "Epoch 355/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 591.3573 - probe_loss: 591.3573\n",
      "Epoch 356/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 585.6307 - probe_loss: 585.6307\n",
      "Epoch 357/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 601.2256 - probe_loss: 601.2256\n",
      "Epoch 358/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 597.2557 - probe_loss: 597.2557\n",
      "Epoch 359/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 568.6415 - probe_loss: 568.6415 - 0s 12ms/step - loss: 597.2834 - probe_loss: 597.2834\n",
      "Epoch 360/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 600.7607 - probe_loss: 600.7607\n",
      "Epoch 361/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 589.5067 - probe_loss: 589.5067\n",
      "Epoch 362/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 586.6518 - probe_loss: 586.6518\n",
      "Epoch 363/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 586.5057 - probe_loss: 586.5057\n",
      "Epoch 364/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 583.0324 - probe_loss: 583.0324\n",
      "Epoch 365/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 579.1048 - probe_loss: 579.1048\n",
      "Epoch 366/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 537.9106 - probe_loss: 537.91 - 0s 11ms/step - loss: 579.5423 - probe_loss: 579.5423\n",
      "Epoch 367/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 577.9291 - probe_loss: 577.9291\n",
      "Epoch 368/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 582.8670 - probe_loss: 582.8670\n",
      "Epoch 369/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 584.2258 - probe_loss: 584.2258\n",
      "Epoch 370/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 600.5858 - probe_loss: 600.5858\n",
      "Epoch 371/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 592.2886 - probe_loss: 592.2886\n",
      "Epoch 372/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 593.5494 - probe_loss: 593.5494\n",
      "Epoch 373/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 595.9157 - probe_loss: 595.9157\n",
      "Epoch 374/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 663.1253 - probe_loss: 663.1253\n",
      "Epoch 375/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 636.9439 - probe_loss: 636.9439\n",
      "Epoch 376/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 624.5339 - probe_loss: 624.5339\n",
      "Epoch 377/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 622.4142 - probe_loss: 622.4142\n",
      "Epoch 378/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 612.6646 - probe_loss: 612.6646\n",
      "Epoch 379/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 604.4747 - probe_loss: 604.4747\n",
      "Epoch 380/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 598.9202 - probe_loss: 598.9202\n",
      "Epoch 381/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 590.9516 - probe_loss: 590.9516\n",
      "Epoch 382/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 625.4510 - probe_loss: 625.4510\n",
      "Epoch 383/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 618.3278 - probe_loss: 618.3278\n",
      "Epoch 384/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 630.2396 - probe_loss: 630.2396\n",
      "Epoch 385/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 616.0624 - probe_loss: 616.0624\n",
      "Epoch 386/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 610.6816 - probe_loss: 610.6816\n",
      "Epoch 387/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 614.7394 - probe_loss: 614.7394\n",
      "Epoch 388/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 603.8817 - probe_loss: 603.8817\n",
      "Epoch 389/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 622.8339 - probe_loss: 622.8339\n",
      "Epoch 390/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 640.0019 - probe_loss: 640.0019\n",
      "Epoch 391/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 630.1259 - probe_loss: 630.1259\n",
      "Epoch 392/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 627.6793 - probe_loss: 627.6793\n",
      "Epoch 393/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 622.4650 - probe_loss: 622.4650\n",
      "Epoch 394/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 619.3619 - probe_loss: 619.3619\n",
      "Epoch 395/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 611.6946 - probe_loss: 611.6946\n",
      "Epoch 396/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 618.2912 - probe_loss: 618.2912\n",
      "Epoch 397/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 610.9307 - probe_loss: 610.9307\n",
      "Epoch 398/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 663.7288 - probe_loss: 663.7288\n",
      "Epoch 399/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 649.4692 - probe_loss: 649.4692\n",
      "Epoch 400/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 668.9117 - probe_loss: 668.9117\n",
      "Epoch 401/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 656.6042 - probe_loss: 656.6042\n",
      "Epoch 402/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 652.3438 - probe_loss: 652.3438\n",
      "Epoch 403/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 641.8646 - probe_loss: 641.8646\n",
      "Epoch 404/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 633.9634 - probe_loss: 633.9634\n",
      "Epoch 405/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 698.3002 - probe_loss: 698.3002\n",
      "Epoch 406/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 677.2133 - probe_loss: 677.2133\n",
      "Epoch 407/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 669.1610 - probe_loss: 669.1610\n",
      "Epoch 408/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 659.9106 - probe_loss: 659.9106\n",
      "Epoch 409/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 655.1733 - probe_loss: 655.1733\n",
      "Epoch 410/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 648.3628 - probe_loss: 648.3628\n",
      "Epoch 411/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 641.5272 - probe_loss: 641.5272\n",
      "Epoch 412/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 634.2867 - probe_loss: 634.2867\n",
      "Epoch 413/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 632.2101 - probe_loss: 632.2101\n",
      "Epoch 414/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 645.9774 - probe_loss: 645.9774\n",
      "Epoch 415/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 638.4523 - probe_loss: 638.4523\n",
      "Epoch 416/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 633.3238 - probe_loss: 633.3238\n",
      "Epoch 417/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 629.1336 - probe_loss: 629.1336\n",
      "Epoch 418/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 623.4518 - probe_loss: 623.4518\n",
      "Epoch 419/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 617.1757 - probe_loss: 617.1757\n",
      "Epoch 420/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 619.0927 - probe_loss: 619.0927\n",
      "Epoch 421/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 611.4393 - probe_loss: 611.4393\n",
      "Epoch 422/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 605.3658 - probe_loss: 605.3658\n",
      "Epoch 423/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 605.1874 - probe_loss: 605.1874\n",
      "Epoch 424/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 602.4634 - probe_loss: 602.4634\n",
      "Epoch 425/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 596.3476 - probe_loss: 596.3476\n",
      "Epoch 426/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 592.7808 - probe_loss: 592.7808\n",
      "Epoch 427/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 591.0153 - probe_loss: 591.0153\n",
      "Epoch 428/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 587.9260 - probe_loss: 587.9260\n",
      "Epoch 429/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 592.8392 - probe_loss: 592.8392\n",
      "Epoch 430/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 585.3832 - probe_loss: 585.3832\n",
      "Epoch 431/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 579.9647 - probe_loss: 579.9647\n",
      "Epoch 432/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 576.8353 - probe_loss: 576.8353\n",
      "Epoch 433/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 578.8058 - probe_loss: 578.8058\n",
      "Epoch 434/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 591.8312 - probe_loss: 591.8312\n",
      "Epoch 435/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 585.5961 - probe_loss: 585.5961\n",
      "Epoch 436/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 585.6333 - probe_loss: 585.6333\n",
      "Epoch 437/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 579.2972 - probe_loss: 579.2972\n",
      "Epoch 438/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 604.3973 - probe_loss: 604.3973\n",
      "Epoch 439/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 606.4039 - probe_loss: 606.4039\n",
      "Epoch 440/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 606.1769 - probe_loss: 606.1769\n",
      "Epoch 441/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 605.4835 - probe_loss: 605.4835\n",
      "Epoch 442/1000\n",
      "7/7 [==============================] - 0s 12ms/step - loss: 603.1639 - probe_loss: 603.1639s - loss: 547.9438 - probe_loss: 547.94\n",
      "Epoch 443/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 601.3193 - probe_loss: 601.3193\n",
      "Epoch 444/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 594.2493 - probe_loss: 594.2493\n",
      "Epoch 445/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 590.9922 - probe_loss: 590.9922\n",
      "Epoch 446/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 611.3176 - probe_loss: 611.3176\n",
      "Epoch 447/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 597.0760 - probe_loss: 597.0760\n",
      "Epoch 448/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 596.0035 - probe_loss: 596.0035\n",
      "Epoch 449/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 590.7625 - probe_loss: 590.7625\n",
      "Epoch 450/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 621.7951 - probe_loss: 621.7951\n",
      "Epoch 451/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 620.1566 - probe_loss: 620.1566\n",
      "Epoch 452/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 622.0589 - probe_loss: 622.0589\n",
      "Epoch 453/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 618.6609 - probe_loss: 618.6609\n",
      "Epoch 454/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 648.2465 - probe_loss: 648.2465\n",
      "Epoch 455/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 640.6476 - probe_loss: 640.6476\n",
      "Epoch 456/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 653.7856 - probe_loss: 653.7856\n",
      "Epoch 457/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 626.4829 - probe_loss: 626.4829\n",
      "Epoch 458/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 622.3253 - probe_loss: 622.3253\n",
      "Epoch 459/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 622.1708 - probe_loss: 622.1708\n",
      "Epoch 460/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 613.6056 - probe_loss: 613.6056\n",
      "Epoch 461/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 605.0363 - probe_loss: 605.0363\n",
      "Epoch 462/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 600.6464 - probe_loss: 600.6464\n",
      "Epoch 463/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 595.7811 - probe_loss: 595.7811\n",
      "Epoch 464/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 596.9898 - probe_loss: 596.9898\n",
      "Epoch 465/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 585.0939 - probe_loss: 585.0939\n",
      "Epoch 466/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 583.1937 - probe_loss: 583.1937\n",
      "Epoch 467/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 582.5082 - probe_loss: 582.5082\n",
      "Epoch 468/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 579.1468 - probe_loss: 579.1468\n",
      "Epoch 469/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 574.6699 - probe_loss: 574.6699\n",
      "Epoch 470/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 578.0186 - probe_loss: 578.0186\n",
      "Epoch 471/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 581.9095 - probe_loss: 581.9095\n",
      "Epoch 472/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 579.1152 - probe_loss: 579.1152\n",
      "Epoch 473/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 578.5765 - probe_loss: 578.5765\n",
      "Epoch 474/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 574.4239 - probe_loss: 574.4239\n",
      "Epoch 475/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 573.4120 - probe_loss: 573.4120\n",
      "Epoch 476/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 570.8270 - probe_loss: 570.8270\n",
      "Epoch 477/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 578.5500 - probe_loss: 578.5500\n",
      "Epoch 478/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 578.8370 - probe_loss: 578.8370\n",
      "Epoch 479/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 574.3051 - probe_loss: 574.3051\n",
      "Epoch 480/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 573.4560 - probe_loss: 573.4560\n",
      "Epoch 481/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 569.5275 - probe_loss: 569.5275\n",
      "Epoch 482/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 568.8550 - probe_loss: 568.8550\n",
      "Epoch 483/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 564.6617 - probe_loss: 564.6617\n",
      "Epoch 484/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 573.1475 - probe_loss: 573.1475\n",
      "Epoch 485/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 581.9235 - probe_loss: 581.9235\n",
      "Epoch 486/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 577.2101 - probe_loss: 577.2101\n",
      "Epoch 487/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 570.5633 - probe_loss: 570.5633\n",
      "Epoch 488/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 567.4924 - probe_loss: 567.4924\n",
      "Epoch 489/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 567.6136 - probe_loss: 567.6136\n",
      "Epoch 490/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 564.1590 - probe_loss: 564.1590\n",
      "Epoch 491/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 556.5430 - probe_loss: 556.5430\n",
      "Epoch 492/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 586.2358 - probe_loss: 586.2358\n",
      "Epoch 493/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 582.2460 - probe_loss: 582.2460\n",
      "Epoch 494/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 589.0704 - probe_loss: 589.0704\n",
      "Epoch 495/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 599.7179 - probe_loss: 599.7179\n",
      "Epoch 496/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 589.5873 - probe_loss: 589.5873\n",
      "Epoch 497/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 604.0765 - probe_loss: 604.0765\n",
      "Epoch 498/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 598.3947 - probe_loss: 598.3947\n",
      "Epoch 499/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 598.2790 - probe_loss: 598.2790\n",
      "Epoch 500/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 595.4209 - probe_loss: 595.4209\n",
      "Epoch 501/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 591.1215 - probe_loss: 591.1215\n",
      "Epoch 502/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 588.9893 - probe_loss: 588.9893\n",
      "Epoch 503/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 585.6896 - probe_loss: 585.6896\n",
      "Epoch 504/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 600.9617 - probe_loss: 600.9617\n",
      "Epoch 505/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 593.0078 - probe_loss: 593.0078\n",
      "Epoch 506/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 591.4068 - probe_loss: 591.4068\n",
      "Epoch 507/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 586.7972 - probe_loss: 586.7972\n",
      "Epoch 508/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 615.6891 - probe_loss: 615.6891\n",
      "Epoch 509/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 584.3366 - probe_loss: 584.3366\n",
      "Epoch 510/1000\n",
      "7/7 [==============================] - 0s 22ms/step - loss: 579.0790 - probe_loss: 579.0790\n",
      "Epoch 511/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 592.3769 - probe_loss: 592.3769\n",
      "Epoch 512/1000\n",
      "7/7 [==============================] - 0s 14ms/step - loss: 586.8004 - probe_loss: 586.8004\n",
      "Epoch 513/1000\n",
      "7/7 [==============================] - 0s 13ms/step - loss: 602.7740 - probe_loss: 602.7740\n",
      "Epoch 514/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 633.1811 - probe_loss: 633.1811\n",
      "Epoch 515/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 619.1845 - probe_loss: 619.1845\n",
      "Epoch 516/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 618.8764 - probe_loss: 618.8764\n",
      "Epoch 517/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 621.5807 - probe_loss: 621.5807\n",
      "Epoch 518/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 610.9613 - probe_loss: 610.9613\n",
      "Epoch 519/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 620.3828 - probe_loss: 620.3828\n",
      "Epoch 520/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 602.4028 - probe_loss: 602.4028\n",
      "Epoch 521/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 682.7926 - probe_loss: 682.7926\n",
      "Epoch 522/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 629.6246 - probe_loss: 629.6246\n",
      "Epoch 523/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 628.7500 - probe_loss: 628.7500\n",
      "Epoch 524/1000\n",
      "7/7 [==============================] - 0s 11ms/step - loss: 623.2040 - probe_loss: 623.2040\n",
      "Epoch 525/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 618.3954 - probe_loss: 618.3954\n",
      "Epoch 526/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 614.8757 - probe_loss: 614.8757\n",
      "Epoch 527/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 604.7767 - probe_loss: 604.7767\n",
      "Epoch 528/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 599.4227 - probe_loss: 599.4227\n",
      "Epoch 529/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 597.9067 - probe_loss: 597.9067\n",
      "Epoch 530/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 591.0096 - probe_loss: 591.0096\n",
      "Epoch 531/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 585.8236 - probe_loss: 585.8236\n",
      "Epoch 532/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 626.4888 - probe_loss: 626.4888\n",
      "Epoch 533/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 617.3252 - probe_loss: 617.3252\n",
      "Epoch 534/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 615.8438 - probe_loss: 615.8438\n",
      "Epoch 535/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 608.2079 - probe_loss: 608.2079\n",
      "Epoch 536/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 605.2802 - probe_loss: 605.2802\n",
      "Epoch 537/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 603.3604 - probe_loss: 603.3604\n",
      "Epoch 538/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 602.6772 - probe_loss: 602.6772\n",
      "Epoch 539/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 612.0377 - probe_loss: 612.0377\n",
      "Epoch 540/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 366.7924 - probe_loss: 366.79 - 0s 7ms/step - loss: 612.0699 - probe_loss: 612.0699\n",
      "Epoch 541/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 607.3891 - probe_loss: 607.3891\n",
      "Epoch 542/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 603.7667 - probe_loss: 603.7667\n",
      "Epoch 543/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 598.8852 - probe_loss: 598.8852\n",
      "Epoch 544/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 597.8683 - probe_loss: 597.8683\n",
      "Epoch 545/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 593.3446 - probe_loss: 593.3446\n",
      "Epoch 546/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 584.7587 - probe_loss: 584.7587\n",
      "Epoch 547/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 595.5040 - probe_loss: 595.5040\n",
      "Epoch 548/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 580.8257 - probe_loss: 580.8257\n",
      "Epoch 549/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 582.5519 - probe_loss: 582.5519\n",
      "Epoch 550/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 581.6049 - probe_loss: 581.6049\n",
      "Epoch 551/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 579.8045 - probe_loss: 579.8045\n",
      "Epoch 552/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 577.8363 - probe_loss: 577.8363\n",
      "Epoch 553/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 573.9730 - probe_loss: 573.9730\n",
      "Epoch 554/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 575.7363 - probe_loss: 575.7363\n",
      "Epoch 555/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 568.4256 - probe_loss: 568.4256\n",
      "Epoch 556/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 571.4175 - probe_loss: 571.4175\n",
      "Epoch 557/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 566.1127 - probe_loss: 566.1127\n",
      "Epoch 558/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 566.7669 - probe_loss: 566.7669\n",
      "Epoch 559/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 569.4000 - probe_loss: 569.4000\n",
      "Epoch 560/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 561.9911 - probe_loss: 561.9911\n",
      "Epoch 561/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 559.3813 - probe_loss: 559.3813\n",
      "Epoch 562/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 559.5118 - probe_loss: 559.5118\n",
      "Epoch 563/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 595.0900 - probe_loss: 595.0900\n",
      "Epoch 564/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 579.8890 - probe_loss: 579.8890\n",
      "Epoch 565/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 577.3519 - probe_loss: 577.3519\n",
      "Epoch 566/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 606.9291 - probe_loss: 606.9291\n",
      "Epoch 567/1000\n",
      "7/7 [==============================] - 0s 8ms/step - loss: 599.4050 - probe_loss: 599.4050\n",
      "Epoch 568/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 587.2328 - probe_loss: 587.2328\n",
      "Epoch 569/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 589.2067 - probe_loss: 589.2067\n",
      "Epoch 570/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 582.9279 - probe_loss: 582.9279\n",
      "Epoch 571/1000\n",
      "7/7 [==============================] - 0s 10ms/step - loss: 596.1555 - probe_loss: 596.1555\n",
      "Epoch 572/1000\n",
      "7/7 [==============================] - 0s 9ms/step - loss: 592.4262 - probe_loss: 592.4262\n",
      "Epoch 573/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 588.3375 - probe_loss: 588.3375\n",
      "Epoch 574/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 587.2778 - probe_loss: 587.2778\n",
      "Epoch 575/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 583.7895 - probe_loss: 583.7895\n",
      "Epoch 576/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.5374 - probe_loss: 581.5374\n",
      "Epoch 577/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 575.7958 - probe_loss: 575.7958\n",
      "Epoch 578/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 578.0394 - probe_loss: 578.0394\n",
      "Epoch 579/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 571.9254 - probe_loss: 571.9254\n",
      "Epoch 580/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 570.0704 - probe_loss: 570.0704\n",
      "Epoch 581/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 597.4113 - probe_loss: 597.4113\n",
      "Epoch 582/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 579.6313 - probe_loss: 579.6313\n",
      "Epoch 583/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 597.2866 - probe_loss: 597.2866\n",
      "Epoch 584/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 592.0468 - probe_loss: 592.0468\n",
      "Epoch 585/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 592.8445 - probe_loss: 592.8445\n",
      "Epoch 586/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.4086 - probe_loss: 581.4086\n",
      "Epoch 587/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 586.3892 - probe_loss: 586.3892\n",
      "Epoch 588/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 583.7046 - probe_loss: 583.7046\n",
      "Epoch 589/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 581.6667 - probe_loss: 581.6667\n",
      "Epoch 590/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 578.8488 - probe_loss: 578.8488\n",
      "Epoch 591/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 577.3304 - probe_loss: 577.3304\n",
      "Epoch 592/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 572.5896 - probe_loss: 572.5896\n",
      "Epoch 593/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 570.8503 - probe_loss: 570.8503\n",
      "Epoch 594/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.5008 - probe_loss: 569.5008\n",
      "Epoch 595/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.6464 - probe_loss: 561.6464\n",
      "Epoch 596/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 561.2205 - probe_loss: 561.2205\n",
      "Epoch 597/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 571.8251 - probe_loss: 571.8251\n",
      "Epoch 598/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 569.1678 - probe_loss: 569.1678\n",
      "Epoch 599/1000\n",
      "7/7 [==============================] - 0s 7ms/step - loss: 567.2254 - probe_loss: 567.2254\n",
      "Epoch 600/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.6639 - probe_loss: 561.6639\n",
      "Epoch 601/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.7686 - probe_loss: 564.7686\n",
      "Epoch 602/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 587.9858 - probe_loss: 587.9858\n",
      "Epoch 603/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 596.8268 - probe_loss: 596.8268\n",
      "Epoch 604/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 593.2935 - probe_loss: 593.2935\n",
      "Epoch 605/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 620.7135 - probe_loss: 620.7135\n",
      "Epoch 606/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 620.4474 - probe_loss: 620.4474\n",
      "Epoch 607/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 625.1384 - probe_loss: 625.1384\n",
      "Epoch 608/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 617.4742 - probe_loss: 617.4742\n",
      "Epoch 609/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 601.8472 - probe_loss: 601.8472\n",
      "Epoch 610/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 608.1094 - probe_loss: 608.1094\n",
      "Epoch 611/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 609.6033 - probe_loss: 609.6033\n",
      "Epoch 612/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 605.0146 - probe_loss: 605.0146\n",
      "Epoch 613/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 601.9938 - probe_loss: 601.9938\n",
      "Epoch 614/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 594.2292 - probe_loss: 594.2292\n",
      "Epoch 615/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 591.6117 - probe_loss: 591.6117\n",
      "Epoch 616/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 586.5349 - probe_loss: 586.5349\n",
      "Epoch 617/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 600.9336 - probe_loss: 600.9336\n",
      "Epoch 618/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.2280 - probe_loss: 576.2280\n",
      "Epoch 619/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.9182 - probe_loss: 575.9182\n",
      "Epoch 620/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 579.4535 - probe_loss: 579.4535\n",
      "Epoch 621/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 572.8929 - probe_loss: 572.8929\n",
      "Epoch 622/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 563.7916 - probe_loss: 563.7916\n",
      "Epoch 623/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 573.1806 - probe_loss: 573.1806\n",
      "Epoch 624/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 571.1304 - probe_loss: 571.1304\n",
      "Epoch 625/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 560.7762 - probe_loss: 560.7762\n",
      "Epoch 626/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 559.4299 - probe_loss: 559.4299\n",
      "Epoch 627/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.8259 - probe_loss: 573.8259\n",
      "Epoch 628/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.1161 - probe_loss: 554.1161\n",
      "Epoch 629/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 552.7723 - probe_loss: 552.7723\n",
      "Epoch 630/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 552.2238 - probe_loss: 552.2238\n",
      "Epoch 631/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 549.9616 - probe_loss: 549.9616\n",
      "Epoch 632/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 551.0507 - probe_loss: 551.0507\n",
      "Epoch 633/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 548.9190 - probe_loss: 548.9190\n",
      "Epoch 634/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 548.5831 - probe_loss: 548.5831\n",
      "Epoch 635/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.9995 - probe_loss: 558.9995\n",
      "Epoch 636/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.1296 - probe_loss: 547.1296\n",
      "Epoch 637/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 552.6367 - probe_loss: 552.6367\n",
      "Epoch 638/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 545.4363 - probe_loss: 545.4363\n",
      "Epoch 639/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 544.7515 - probe_loss: 544.7515\n",
      "Epoch 640/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.2314 - probe_loss: 542.2314\n",
      "Epoch 641/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.6891 - probe_loss: 542.6891\n",
      "Epoch 642/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.1378 - probe_loss: 542.1378\n",
      "Epoch 643/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 542.3021 - probe_loss: 542.3021\n",
      "Epoch 644/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.1857 - probe_loss: 542.1857\n",
      "Epoch 645/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 541.5760 - probe_loss: 541.5760\n",
      "Epoch 646/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 540.2103 - probe_loss: 540.2103\n",
      "Epoch 647/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 533.8073 - probe_loss: 533.8073\n",
      "Epoch 648/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 529.8331 - probe_loss: 529.8331\n",
      "Epoch 649/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 549.6931 - probe_loss: 549.6931\n",
      "Epoch 650/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 563.7172 - probe_loss: 563.7172\n",
      "Epoch 651/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.7221 - probe_loss: 553.7221\n",
      "Epoch 652/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 550.4779 - probe_loss: 550.4779\n",
      "Epoch 653/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 546.3671 - probe_loss: 546.3671\n",
      "Epoch 654/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 544.8984 - probe_loss: 544.8984\n",
      "Epoch 655/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 549.7787 - probe_loss: 549.7787\n",
      "Epoch 656/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 548.9753 - probe_loss: 548.9753\n",
      "Epoch 657/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 544.8705 - probe_loss: 544.8705\n",
      "Epoch 658/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 543.6110 - probe_loss: 543.6110\n",
      "Epoch 659/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.5115 - probe_loss: 542.5115\n",
      "Epoch 660/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 539.6393 - probe_loss: 539.6393\n",
      "Epoch 661/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 535.1563 - probe_loss: 535.1563\n",
      "Epoch 662/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 577.7555 - probe_loss: 577.7555\n",
      "Epoch 663/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.2477 - probe_loss: 564.2477\n",
      "Epoch 664/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.4059 - probe_loss: 567.4059\n",
      "Epoch 665/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 565.2885 - probe_loss: 565.2885\n",
      "Epoch 666/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.2460 - probe_loss: 568.2460\n",
      "Epoch 667/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.4683 - probe_loss: 564.4683\n",
      "Epoch 668/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.4048 - probe_loss: 569.4048\n",
      "Epoch 669/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.3570 - probe_loss: 573.3570\n",
      "Epoch 670/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 577.3295 - probe_loss: 577.3295\n",
      "Epoch 671/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.8125 - probe_loss: 588.8125\n",
      "Epoch 672/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 596.6802 - probe_loss: 596.6802\n",
      "Epoch 673/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.7220 - probe_loss: 588.7220\n",
      "Epoch 674/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 582.6360 - probe_loss: 582.6360\n",
      "Epoch 675/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 579.8666 - probe_loss: 579.8666\n",
      "Epoch 676/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.7156 - probe_loss: 576.7156\n",
      "Epoch 677/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.1970 - probe_loss: 575.1970\n",
      "Epoch 678/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 570.9076 - probe_loss: 570.9076\n",
      "Epoch 679/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.2498 - probe_loss: 568.2498\n",
      "Epoch 680/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 562.7910 - probe_loss: 562.7910\n",
      "Epoch 681/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 570.0826 - probe_loss: 570.0826\n",
      "Epoch 682/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 560.3029 - probe_loss: 560.3029\n",
      "Epoch 683/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.1100 - probe_loss: 581.1100\n",
      "Epoch 684/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.7006 - probe_loss: 573.7006\n",
      "Epoch 685/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.4578 - probe_loss: 569.4578\n",
      "Epoch 686/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 577.8932 - probe_loss: 577.8932\n",
      "Epoch 687/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 583.6464 - probe_loss: 583.6464\n",
      "Epoch 688/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.7979 - probe_loss: 575.7979\n",
      "Epoch 689/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.1147 - probe_loss: 575.1147\n",
      "Epoch 690/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.1532 - probe_loss: 584.1532\n",
      "Epoch 691/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.3749 - probe_loss: 576.3749\n",
      "Epoch 692/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.2837 - probe_loss: 584.2837\n",
      "Epoch 693/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 585.6310 - probe_loss: 585.6310\n",
      "Epoch 694/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 578.4078 - probe_loss: 578.4078\n",
      "Epoch 695/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 581.9379 - probe_loss: 581.9379\n",
      "Epoch 696/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.2944 - probe_loss: 581.2944\n",
      "Epoch 697/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 579.3067 - probe_loss: 579.3067\n",
      "Epoch 698/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.7488 - probe_loss: 573.7488\n",
      "Epoch 699/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 577.1327 - probe_loss: 577.1327\n",
      "Epoch 700/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.7604 - probe_loss: 575.7604\n",
      "Epoch 701/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.4246 - probe_loss: 567.4246\n",
      "Epoch 702/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.2449 - probe_loss: 567.2449\n",
      "Epoch 703/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 571.5223 - probe_loss: 571.5223\n",
      "Epoch 704/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.1999 - probe_loss: 568.1999\n",
      "Epoch 705/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 605.7506 - probe_loss: 605.7506\n",
      "Epoch 706/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 596.6563 - probe_loss: 596.6563\n",
      "Epoch 707/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 594.5905 - probe_loss: 594.5905\n",
      "Epoch 708/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.1830 - probe_loss: 590.1830\n",
      "Epoch 709/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.8947 - probe_loss: 584.8947\n",
      "Epoch 710/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 583.5894 - probe_loss: 583.5894\n",
      "Epoch 711/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.6564 - probe_loss: 575.6564\n",
      "Epoch 712/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.8598 - probe_loss: 573.8598\n",
      "Epoch 713/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 570.1779 - probe_loss: 570.1779\n",
      "Epoch 714/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 566.9837 - probe_loss: 566.9837\n",
      "Epoch 715/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 570.7744 - probe_loss: 570.7744\n",
      "Epoch 716/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 570.6324 - probe_loss: 570.6324\n",
      "Epoch 717/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.7873 - probe_loss: 561.7873\n",
      "Epoch 718/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 562.0452 - probe_loss: 562.0452\n",
      "Epoch 719/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.2234 - probe_loss: 558.2234\n",
      "Epoch 720/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.6179 - probe_loss: 555.6179\n",
      "Epoch 721/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.9080 - probe_loss: 554.9080\n",
      "Epoch 722/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 556.1928 - probe_loss: 556.1928\n",
      "Epoch 723/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.1298 - probe_loss: 569.1298\n",
      "Epoch 724/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.9996 - probe_loss: 566.9996\n",
      "Epoch 725/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.8837 - probe_loss: 564.8837\n",
      "Epoch 726/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 557.8898 - probe_loss: 557.8898\n",
      "Epoch 727/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.2305 - probe_loss: 561.2305\n",
      "Epoch 728/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 559.3005 - probe_loss: 559.3005\n",
      "Epoch 729/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.3613 - probe_loss: 553.3613\n",
      "Epoch 730/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 551.3517 - probe_loss: 551.3517\n",
      "Epoch 731/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.6605 - probe_loss: 569.6605\n",
      "Epoch 732/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.1586 - probe_loss: 564.1586\n",
      "Epoch 733/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.8408 - probe_loss: 561.8408\n",
      "Epoch 734/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 563.4835 - probe_loss: 563.4835\n",
      "Epoch 735/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.7148 - probe_loss: 561.7148\n",
      "Epoch 736/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 559.7460 - probe_loss: 559.7460\n",
      "Epoch 737/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 560.1421 - probe_loss: 560.1421\n",
      "Epoch 738/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 557.6495 - probe_loss: 557.6495\n",
      "Epoch 739/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.4310 - probe_loss: 553.4310\n",
      "Epoch 740/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 551.7474 - probe_loss: 551.7474\n",
      "Epoch 741/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.1564 - probe_loss: 553.1564\n",
      "Epoch 742/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 551.8918 - probe_loss: 551.8918\n",
      "Epoch 743/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 582.5698 - probe_loss: 582.5698\n",
      "Epoch 744/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.9647 - probe_loss: 567.9647\n",
      "Epoch 745/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.4777 - probe_loss: 566.4777\n",
      "Epoch 746/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.6666 - probe_loss: 558.6666\n",
      "Epoch 747/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 558.1878 - probe_loss: 558.1878\n",
      "Epoch 748/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 597.5521 - probe_loss: 597.5521\n",
      "Epoch 749/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 595.5756 - probe_loss: 595.5756\n",
      "Epoch 750/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 588.9481 - probe_loss: 588.9481\n",
      "Epoch 751/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 587.2076 - probe_loss: 587.2076\n",
      "Epoch 752/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.9398 - probe_loss: 581.9398\n",
      "Epoch 753/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 579.1210 - probe_loss: 579.1210\n",
      "Epoch 754/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.9015 - probe_loss: 569.9015\n",
      "Epoch 755/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 585.8832 - probe_loss: 585.8832\n",
      "Epoch 756/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 572.4204 - probe_loss: 572.4204\n",
      "Epoch 757/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 602.8548 - probe_loss: 602.8548\n",
      "Epoch 758/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 585.4379 - probe_loss: 585.4379\n",
      "Epoch 759/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 596.2630 - probe_loss: 596.2630\n",
      "Epoch 760/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.8307 - probe_loss: 581.8307\n",
      "Epoch 761/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 577.0168 - probe_loss: 577.0168\n",
      "Epoch 762/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 572.8630 - probe_loss: 572.8630\n",
      "Epoch 763/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 571.6048 - probe_loss: 571.6048\n",
      "Epoch 764/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.3500 - probe_loss: 566.3500\n",
      "Epoch 765/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 577.8005 - probe_loss: 577.8005\n",
      "Epoch 766/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.6617 - probe_loss: 576.6617\n",
      "Epoch 767/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 573.7377 - probe_loss: 573.7377\n",
      "Epoch 768/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.7875 - probe_loss: 576.7875\n",
      "Epoch 769/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 577.6519 - probe_loss: 577.6519\n",
      "Epoch 770/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.3651 - probe_loss: 574.3651\n",
      "Epoch 771/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.5631 - probe_loss: 567.5631\n",
      "Epoch 772/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 562.9032 - probe_loss: 562.9032\n",
      "Epoch 773/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 563.6277 - probe_loss: 563.6277\n",
      "Epoch 774/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 559.3553 - probe_loss: 559.3553\n",
      "Epoch 775/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.7955 - probe_loss: 564.7955\n",
      "Epoch 776/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.0259 - probe_loss: 574.0259\n",
      "Epoch 777/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.5231 - probe_loss: 569.5231\n",
      "Epoch 778/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 587.8214 - probe_loss: 587.8214\n",
      "Epoch 779/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 615.8198 - probe_loss: 615.8198\n",
      "Epoch 780/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 603.5123 - probe_loss: 603.5123\n",
      "Epoch 781/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 595.2208 - probe_loss: 595.2208\n",
      "Epoch 782/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.8746 - probe_loss: 588.8746\n",
      "Epoch 783/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 586.4872 - probe_loss: 586.4872\n",
      "Epoch 784/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 581.1465 - probe_loss: 581.1465\n",
      "Epoch 785/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 574.5104 - probe_loss: 574.5104\n",
      "Epoch 786/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.0090 - probe_loss: 581.0090\n",
      "Epoch 787/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 578.1472 - probe_loss: 578.1472\n",
      "Epoch 788/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.4047 - probe_loss: 574.4047\n",
      "Epoch 789/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.3096 - probe_loss: 569.3096\n",
      "Epoch 790/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 604.7862 - probe_loss: 604.7862\n",
      "Epoch 791/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 586.8101 - probe_loss: 586.8101\n",
      "Epoch 792/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 582.7313 - probe_loss: 582.7313\n",
      "Epoch 793/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 578.5572 - probe_loss: 578.5572\n",
      "Epoch 794/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.6805 - probe_loss: 576.6805\n",
      "Epoch 795/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.3120 - probe_loss: 574.3120\n",
      "Epoch 796/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 570.2922 - probe_loss: 570.2922\n",
      "Epoch 797/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.7888 - probe_loss: 566.7888\n",
      "Epoch 798/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 565.2031 - probe_loss: 565.2031\n",
      "Epoch 799/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.5435 - probe_loss: 564.5435\n",
      "Epoch 800/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.5016 - probe_loss: 561.5016\n",
      "Epoch 801/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.3207 - probe_loss: 564.3207\n",
      "Epoch 802/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 557.5223 - probe_loss: 557.5223\n",
      "Epoch 803/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.5425 - probe_loss: 558.5425\n",
      "Epoch 804/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 556.0696 - probe_loss: 556.0696\n",
      "Epoch 805/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.8574 - probe_loss: 554.8574\n",
      "Epoch 806/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.0897 - probe_loss: 553.0897\n",
      "Epoch 807/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.7892 - probe_loss: 554.7892\n",
      "Epoch 808/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.3223 - probe_loss: 553.3223\n",
      "Epoch 809/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.8633 - probe_loss: 584.8633\n",
      "Epoch 810/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.5020 - probe_loss: 584.5020\n",
      "Epoch 811/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 603.1683 - probe_loss: 603.1683\n",
      "Epoch 812/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 605.1649 - probe_loss: 605.1649\n",
      "Epoch 813/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 595.9249 - probe_loss: 595.9249\n",
      "Epoch 814/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 595.2875 - probe_loss: 595.2875\n",
      "Epoch 815/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 592.1212 - probe_loss: 592.1212\n",
      "Epoch 816/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 598.5218 - probe_loss: 598.5218\n",
      "Epoch 817/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 613.4684 - probe_loss: 613.4684\n",
      "Epoch 818/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 609.8310 - probe_loss: 609.8310\n",
      "Epoch 819/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 606.7988 - probe_loss: 606.7988\n",
      "Epoch 820/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 598.9248 - probe_loss: 598.9248\n",
      "Epoch 821/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 595.5565 - probe_loss: 595.5565\n",
      "Epoch 822/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 593.7536 - probe_loss: 593.7536\n",
      "Epoch 823/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 604.3682 - probe_loss: 604.3682\n",
      "Epoch 824/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.3387 - probe_loss: 590.3387\n",
      "Epoch 825/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.8017 - probe_loss: 590.8017\n",
      "Epoch 826/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.6198 - probe_loss: 569.6198\n",
      "Epoch 827/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.5956 - probe_loss: 584.5956\n",
      "Epoch 828/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 572.5328 - probe_loss: 572.5328\n",
      "Epoch 829/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 621.7311 - probe_loss: 621.7311\n",
      "Epoch 830/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 612.7260 - probe_loss: 612.7260\n",
      "Epoch 831/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 594.5103 - probe_loss: 594.5103\n",
      "Epoch 832/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.5887 - probe_loss: 588.5887\n",
      "Epoch 833/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 585.8515 - probe_loss: 585.8515\n",
      "Epoch 834/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 598.9232 - probe_loss: 598.9232\n",
      "Epoch 835/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.8219 - probe_loss: 590.8219\n",
      "Epoch 836/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.7379 - probe_loss: 590.7379\n",
      "Epoch 837/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.2433 - probe_loss: 581.2433\n",
      "Epoch 838/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 572.1702 - probe_loss: 572.1702\n",
      "Epoch 839/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.7165 - probe_loss: 561.7165\n",
      "Epoch 840/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.7180 - probe_loss: 555.7180\n",
      "Epoch 841/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.6649 - probe_loss: 568.6649\n",
      "Epoch 842/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.1248 - probe_loss: 555.1248\n",
      "Epoch 843/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.3795 - probe_loss: 558.3795\n",
      "Epoch 844/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.5519 - probe_loss: 555.5519\n",
      "Epoch 845/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 560.6807 - probe_loss: 560.6807\n",
      "Epoch 846/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 557.8397 - probe_loss: 557.8397\n",
      "Epoch 847/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 563.4396 - probe_loss: 563.4396\n",
      "Epoch 848/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 549.6442 - probe_loss: 549.6442\n",
      "Epoch 849/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 545.8920 - probe_loss: 545.8920\n",
      "Epoch 850/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 549.8326 - probe_loss: 549.8326\n",
      "Epoch 851/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.5280 - probe_loss: 547.5280\n",
      "Epoch 852/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 546.6337 - probe_loss: 546.6337\n",
      "Epoch 853/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 558.7592 - probe_loss: 558.7592\n",
      "Epoch 854/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 545.4398 - probe_loss: 545.4398\n",
      "Epoch 855/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 548.7070 - probe_loss: 548.7070\n",
      "Epoch 856/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 543.2141 - probe_loss: 543.2141\n",
      "Epoch 857/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 549.2039 - probe_loss: 549.2039\n",
      "Epoch 858/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.7767 - probe_loss: 547.7767\n",
      "Epoch 859/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 546.4532 - probe_loss: 546.4532\n",
      "Epoch 860/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 545.6538 - probe_loss: 545.6538\n",
      "Epoch 861/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 557.4478 - probe_loss: 557.4478\n",
      "Epoch 862/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 558.3729 - probe_loss: 558.3729\n",
      "Epoch 863/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 553.3449 - probe_loss: 553.3449\n",
      "Epoch 864/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 556.4827 - probe_loss: 556.4827\n",
      "Epoch 865/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.7210 - probe_loss: 555.7210\n",
      "Epoch 866/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 583.4546 - probe_loss: 583.4546\n",
      "Epoch 867/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 589.0974 - probe_loss: 589.0974\n",
      "Epoch 868/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 583.3627 - probe_loss: 583.3627\n",
      "Epoch 869/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.4622 - probe_loss: 576.4622\n",
      "Epoch 870/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 569.8414 - probe_loss: 569.8414\n",
      "Epoch 871/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.9839 - probe_loss: 566.9839\n",
      "Epoch 872/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.4276 - probe_loss: 574.4276\n",
      "Epoch 873/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 593.4274 - probe_loss: 593.4274\n",
      "Epoch 874/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 585.2889 - probe_loss: 585.2889\n",
      "Epoch 875/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 587.0112 - probe_loss: 587.0112\n",
      "Epoch 876/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.1366 - probe_loss: 568.1366\n",
      "Epoch 877/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 598.4543 - probe_loss: 598.4543\n",
      "Epoch 878/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 600.7775 - probe_loss: 600.7775\n",
      "Epoch 879/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 599.9206 - probe_loss: 599.9206\n",
      "Epoch 880/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 586.8968 - probe_loss: 586.8968\n",
      "Epoch 881/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 581.5505 - probe_loss: 581.5505\n",
      "Epoch 882/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 579.1615 - probe_loss: 579.1615\n",
      "Epoch 883/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 575.1427 - probe_loss: 575.1427\n",
      "Epoch 884/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 584.5135 - probe_loss: 584.5135\n",
      "Epoch 885/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 596.2868 - probe_loss: 596.2868\n",
      "Epoch 886/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 629.5237 - probe_loss: 629.5237\n",
      "Epoch 887/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 594.7134 - probe_loss: 594.7134\n",
      "Epoch 888/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 615.6142 - probe_loss: 615.6142\n",
      "Epoch 889/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 628.8502 - probe_loss: 628.8502\n",
      "Epoch 890/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 603.1404 - probe_loss: 603.1404\n",
      "Epoch 891/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 611.1237 - probe_loss: 611.1237\n",
      "Epoch 892/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 591.9201 - probe_loss: 591.9201\n",
      "Epoch 893/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 594.0596 - probe_loss: 594.0596\n",
      "Epoch 894/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 578.6826 - probe_loss: 578.6826\n",
      "Epoch 895/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 593.2734 - probe_loss: 593.2734\n",
      "Epoch 896/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 614.9648 - probe_loss: 614.9648\n",
      "Epoch 897/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 608.1611 - probe_loss: 608.1611\n",
      "Epoch 898/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 597.8793 - probe_loss: 597.8793\n",
      "Epoch 899/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 595.7411 - probe_loss: 595.7411\n",
      "Epoch 900/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 582.7426 - probe_loss: 582.7426\n",
      "Epoch 901/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.1089 - probe_loss: 590.1089\n",
      "Epoch 902/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 575.1191 - probe_loss: 575.1191\n",
      "Epoch 903/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 570.3359 - probe_loss: 570.3359\n",
      "Epoch 904/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 578.3569 - probe_loss: 578.3569\n",
      "Epoch 905/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 593.8444 - probe_loss: 593.8444\n",
      "Epoch 906/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.4861 - probe_loss: 588.4861\n",
      "Epoch 907/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 580.1949 - probe_loss: 580.1949\n",
      "Epoch 908/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 612.0018 - probe_loss: 612.0018\n",
      "Epoch 909/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 603.1609 - probe_loss: 603.1609\n",
      "Epoch 910/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 601.3497 - probe_loss: 601.3497\n",
      "Epoch 911/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 593.5911 - probe_loss: 593.5911\n",
      "Epoch 912/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.0352 - probe_loss: 588.0352\n",
      "Epoch 913/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 588.1776 - probe_loss: 588.1776\n",
      "Epoch 914/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 586.5046 - probe_loss: 586.5046\n",
      "Epoch 915/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 574.7654 - probe_loss: 574.7654\n",
      "Epoch 916/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 576.9178 - probe_loss: 576.9178\n",
      "Epoch 917/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 567.5049 - probe_loss: 567.5049\n",
      "Epoch 918/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 566.7918 - probe_loss: 566.7918\n",
      "Epoch 919/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 561.9572 - probe_loss: 561.9572\n",
      "Epoch 920/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 557.4761 - probe_loss: 557.4761\n",
      "Epoch 921/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 558.4327 - probe_loss: 558.4327\n",
      "Epoch 922/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 552.8441 - probe_loss: 552.8441\n",
      "Epoch 923/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 566.1600 - probe_loss: 566.1600\n",
      "Epoch 924/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 580.7986 - probe_loss: 580.7986\n",
      "Epoch 925/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.6590 - probe_loss: 568.6590\n",
      "Epoch 926/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 571.6916 - probe_loss: 571.6916\n",
      "Epoch 927/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 561.0067 - probe_loss: 561.0067\n",
      "Epoch 928/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 560.8048 - probe_loss: 560.8048\n",
      "Epoch 929/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 558.1370 - probe_loss: 558.1370\n",
      "Epoch 930/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.7991 - probe_loss: 554.7991\n",
      "Epoch 931/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.6403 - probe_loss: 547.6403\n",
      "Epoch 932/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 544.5962 - probe_loss: 544.5962\n",
      "Epoch 933/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 541.7227 - probe_loss: 541.7227\n",
      "Epoch 934/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 539.5596 - probe_loss: 539.5596\n",
      "Epoch 935/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 532.9878 - probe_loss: 532.9878\n",
      "Epoch 936/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 531.3470 - probe_loss: 531.3470\n",
      "Epoch 937/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 560.3173 - probe_loss: 560.3173\n",
      "Epoch 938/1000\n",
      "7/7 [==============================] - ETA: 0s - loss: 798.0435 - probe_loss: 798.04 - 0s 5ms/step - loss: 547.5110 - probe_loss: 547.5110\n",
      "Epoch 939/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 600.3407 - probe_loss: 600.3407\n",
      "Epoch 940/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 579.0449 - probe_loss: 579.0449\n",
      "Epoch 941/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 568.1705 - probe_loss: 568.1705\n",
      "Epoch 942/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 586.7990 - probe_loss: 586.7990\n",
      "Epoch 943/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 591.9809 - probe_loss: 591.9809\n",
      "Epoch 944/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 590.8312 - probe_loss: 590.8312\n",
      "Epoch 945/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 587.2065 - probe_loss: 587.2065\n",
      "Epoch 946/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 583.7780 - probe_loss: 583.7780\n",
      "Epoch 947/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 570.2384 - probe_loss: 570.2384\n",
      "Epoch 948/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 563.0458 - probe_loss: 563.0458\n",
      "Epoch 949/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 556.0541 - probe_loss: 556.0541\n",
      "Epoch 950/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 554.3471 - probe_loss: 554.3471\n",
      "Epoch 951/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 549.7900 - probe_loss: 549.7900\n",
      "Epoch 952/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 546.6344 - probe_loss: 546.6344\n",
      "Epoch 953/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.6828 - probe_loss: 542.6828\n",
      "Epoch 954/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 536.3724 - probe_loss: 536.3724\n",
      "Epoch 955/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 537.9022 - probe_loss: 537.9022\n",
      "Epoch 956/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 566.5738 - probe_loss: 566.5738\n",
      "Epoch 957/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 551.2518 - probe_loss: 551.2518\n",
      "Epoch 958/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 545.9444 - probe_loss: 545.9444\n",
      "Epoch 959/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 536.2136 - probe_loss: 536.2136\n",
      "Epoch 960/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 536.8332 - probe_loss: 536.8332\n",
      "Epoch 961/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 529.6332 - probe_loss: 529.6332\n",
      "Epoch 962/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 524.8716 - probe_loss: 524.8716\n",
      "Epoch 963/1000\n",
      "7/7 [==============================] - 0s 6ms/step - loss: 549.2846 - probe_loss: 549.2846\n",
      "Epoch 964/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 540.1649 - probe_loss: 540.1649\n",
      "Epoch 965/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 539.1598 - probe_loss: 539.1598\n",
      "Epoch 966/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 532.2335 - probe_loss: 532.2335\n",
      "Epoch 967/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 530.8475 - probe_loss: 530.8475\n",
      "Epoch 968/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 529.7004 - probe_loss: 529.7004\n",
      "Epoch 969/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 533.0681 - probe_loss: 533.0681\n",
      "Epoch 970/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 527.2133 - probe_loss: 527.2133\n",
      "Epoch 971/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 521.1720 - probe_loss: 521.1720\n",
      "Epoch 972/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 525.4305 - probe_loss: 525.4305\n",
      "Epoch 973/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 527.3287 - probe_loss: 527.3287\n",
      "Epoch 974/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 523.3022 - probe_loss: 523.3022\n",
      "Epoch 975/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 518.4117 - probe_loss: 518.4117\n",
      "Epoch 976/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 521.9771 - probe_loss: 521.9771\n",
      "Epoch 977/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 518.1937 - probe_loss: 518.1937\n",
      "Epoch 978/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 544.7620 - probe_loss: 544.7620\n",
      "Epoch 979/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 539.9117 - probe_loss: 539.9117\n",
      "Epoch 980/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 532.6480 - probe_loss: 532.6480\n",
      "Epoch 981/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 530.3130 - probe_loss: 530.3130\n",
      "Epoch 982/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 525.6237 - probe_loss: 525.6237\n",
      "Epoch 983/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 523.6122 - probe_loss: 523.6122\n",
      "Epoch 984/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.4417 - probe_loss: 542.4417\n",
      "Epoch 985/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 538.2534 - probe_loss: 538.2534\n",
      "Epoch 986/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 536.9567 - probe_loss: 536.9567\n",
      "Epoch 987/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 532.5106 - probe_loss: 532.5106\n",
      "Epoch 988/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 537.4688 - probe_loss: 537.4688\n",
      "Epoch 989/1000\n",
      "7/7 [==============================] - 0s 5ms/step - loss: 529.9716 - probe_loss: 529.9716\n",
      "Epoch 990/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 564.4065 - probe_loss: 564.4065\n",
      "Epoch 991/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 559.9389 - probe_loss: 559.9389\n",
      "Epoch 992/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 552.3362 - probe_loss: 552.3362\n",
      "Epoch 993/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 552.8478 - probe_loss: 552.8478\n",
      "Epoch 994/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.7865 - probe_loss: 547.7865\n",
      "Epoch 995/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 547.8056 - probe_loss: 547.8056\n",
      "Epoch 996/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 542.5229 - probe_loss: 542.5229\n",
      "Epoch 997/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 539.2662 - probe_loss: 539.2662\n",
      "Epoch 998/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 536.7119 - probe_loss: 536.7119\n",
      "Epoch 999/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 573.5026 - probe_loss: 573.5026\n",
      "Epoch 1000/1000\n",
      "7/7 [==============================] - 0s 4ms/step - loss: 555.2248 - probe_loss: 555.2248\n",
      "{<Probe at 0x1b955a57148 of 'output' of <Node (unlabeled) at 0x1b955a3e708>>: array([[[116.60262],\n",
      "        [179.56796],\n",
      "        [185.50494]]], dtype=float32)}\n"
     ]
    }
   ],
   "source": [
    "import nengo\n",
    "import tensorflow as tf\n",
    "import numpy as np\n",
    "import nengo_dl\n",
    "import matplotlib.pyplot as plt\n",
    "n_steps = 3\n",
    "x_train = np.array([[[10, 15], [20, 25], [30, 35]],\n",
    "                    [[20, 25], [30, 35], [40, 45]],\n",
    "                    [[30, 35], [40, 45], [50, 55]],\n",
    "                    [[40, 45], [50, 55], [60, 65]],\n",
    "                    [[50, 55], [60, 65], [70, 75]],\n",
    "                    [[60, 65], [70, 75], [80, 85]],\n",
    "                    [[70, 75], [80, 85], [90, 95]]])\n",
    "print(x_train.shape)\n",
    "n_features = x_train.shape[2]\n",
    "y_train = np.array([[[65]], [[85]], [[105]], [[125]], [[145]], [[165]], [[185]]])\n",
    "x_test = np.array([[[80, 85], [90, 95], [100, 105]]])\n",
    "y_test = np.array([[206.0161]])\n",
    "\n",
    "print(x_test.shape)\n",
    "\n",
    "with nengo.Network() as net:\n",
    "    # remove some unnecessary features to speed up the training\n",
    "    nengo_dl.configure_settings(\n",
    "        trainable=None,\n",
    "        stateful=None,\n",
    "        keep_history=True,\n",
    "    )\n",
    "\n",
    "    inp = nengo.Node((np.zeros(x_train.shape[-1])))\n",
    "    # lmu cell\n",
    "    lmu = LMUCell(\n",
    "        units=256,\n",
    "        order=256,\n",
    "        theta=x_train.shape[1],\n",
    "        input_d=x_train.shape[-1],\n",
    "    )\n",
    "    \n",
    "\n",
    "    conn = nengo.Connection(inp, lmu.x, synapse=None)\n",
    "    net.config[conn].trainable = True    \n",
    "    \n",
    "    \n",
    " \n",
    "    # dense linear readout \n",
    "    out = nengo.Node(size_in=1) #changed to 1\n",
    "    nengo.Connection(lmu.h, out,transform=nengo_dl.dists.Glorot(), synapse=None)\n",
    "   \n",
    "    p = nengo.Probe(out)   \n",
    "\n",
    "    \n",
    "with nengo_dl.Simulator(net) as sim:\n",
    "    sim.compile(\n",
    "        loss=tf.losses.mse,\n",
    "        optimizer=tf.optimizers.Adam(),\n",
    "#         metrics=[\"mse\"],\n",
    "    )\n",
    "\n",
    "    sim.fit(x_train, y_train, epochs=1000)\n",
    "#     sim.save_params(\"./lmu_params\")\n",
    "    print(sim.predict(x_test))\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<font color='red' size=5><b>Real Data</b></font>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now I will try to use the LMU model on S&P500 time series data\n",
    "I will only select a subsample of the data to train\n",
    "When I run on the real data model predicts the same value for all samples"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 140,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Date</th>\n",
       "      <th>High</th>\n",
       "      <th>Low</th>\n",
       "      <th>Open</th>\n",
       "      <th>Close</th>\n",
       "      <th>Volume</th>\n",
       "      <th>Adj Close</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>02/01/1990</td>\n",
       "      <td>359.690002</td>\n",
       "      <td>351.980011</td>\n",
       "      <td>353.399994</td>\n",
       "      <td>359.690002</td>\n",
       "      <td>162070000</td>\n",
       "      <td>359.690002</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>03/01/1990</td>\n",
       "      <td>360.589996</td>\n",
       "      <td>357.890015</td>\n",
       "      <td>359.690002</td>\n",
       "      <td>358.760010</td>\n",
       "      <td>192330000</td>\n",
       "      <td>358.760010</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>04/01/1990</td>\n",
       "      <td>358.760010</td>\n",
       "      <td>352.890015</td>\n",
       "      <td>358.760010</td>\n",
       "      <td>355.670013</td>\n",
       "      <td>177000000</td>\n",
       "      <td>355.670013</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>05/01/1990</td>\n",
       "      <td>355.670013</td>\n",
       "      <td>351.350006</td>\n",
       "      <td>355.670013</td>\n",
       "      <td>352.200012</td>\n",
       "      <td>158530000</td>\n",
       "      <td>352.200012</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>08/01/1990</td>\n",
       "      <td>354.239990</td>\n",
       "      <td>350.540008</td>\n",
       "      <td>352.200012</td>\n",
       "      <td>353.790008</td>\n",
       "      <td>140110000</td>\n",
       "      <td>353.790008</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7807</th>\n",
       "      <td>24/12/2020</td>\n",
       "      <td>3703.820068</td>\n",
       "      <td>3689.320068</td>\n",
       "      <td>3694.030029</td>\n",
       "      <td>3703.060059</td>\n",
       "      <td>1885090000</td>\n",
       "      <td>3703.060059</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7808</th>\n",
       "      <td>28/12/2020</td>\n",
       "      <td>3740.510010</td>\n",
       "      <td>3723.030029</td>\n",
       "      <td>3723.030029</td>\n",
       "      <td>3735.360107</td>\n",
       "      <td>3527460000</td>\n",
       "      <td>3735.360107</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7809</th>\n",
       "      <td>29/12/2020</td>\n",
       "      <td>3756.120117</td>\n",
       "      <td>3723.310059</td>\n",
       "      <td>3750.010010</td>\n",
       "      <td>3727.040039</td>\n",
       "      <td>3387030000</td>\n",
       "      <td>3727.040039</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7810</th>\n",
       "      <td>30/12/2020</td>\n",
       "      <td>3744.629883</td>\n",
       "      <td>3730.209961</td>\n",
       "      <td>3736.189941</td>\n",
       "      <td>3732.040039</td>\n",
       "      <td>3145200000</td>\n",
       "      <td>3732.040039</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7811</th>\n",
       "      <td>31/12/2020</td>\n",
       "      <td>3760.199951</td>\n",
       "      <td>3726.879883</td>\n",
       "      <td>3733.270020</td>\n",
       "      <td>3756.070068</td>\n",
       "      <td>3172510000</td>\n",
       "      <td>3756.070068</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>7812 rows × 7 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "            Date         High          Low         Open        Close  \\\n",
       "0     02/01/1990   359.690002   351.980011   353.399994   359.690002   \n",
       "1     03/01/1990   360.589996   357.890015   359.690002   358.760010   \n",
       "2     04/01/1990   358.760010   352.890015   358.760010   355.670013   \n",
       "3     05/01/1990   355.670013   351.350006   355.670013   352.200012   \n",
       "4     08/01/1990   354.239990   350.540008   352.200012   353.790008   \n",
       "...          ...          ...          ...          ...          ...   \n",
       "7807  24/12/2020  3703.820068  3689.320068  3694.030029  3703.060059   \n",
       "7808  28/12/2020  3740.510010  3723.030029  3723.030029  3735.360107   \n",
       "7809  29/12/2020  3756.120117  3723.310059  3750.010010  3727.040039   \n",
       "7810  30/12/2020  3744.629883  3730.209961  3736.189941  3732.040039   \n",
       "7811  31/12/2020  3760.199951  3726.879883  3733.270020  3756.070068   \n",
       "\n",
       "          Volume    Adj Close  \n",
       "0      162070000   359.690002  \n",
       "1      192330000   358.760010  \n",
       "2      177000000   355.670013  \n",
       "3      158530000   352.200012  \n",
       "4      140110000   353.790008  \n",
       "...          ...          ...  \n",
       "7807  1885090000  3703.060059  \n",
       "7808  3527460000  3735.360107  \n",
       "7809  3387030000  3727.040039  \n",
       "7810  3145200000  3732.040039  \n",
       "7811  3172510000  3756.070068  \n",
       "\n",
       "[7812 rows x 7 columns]"
      ]
     },
     "execution_count": 140,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "from datetime import datetime\n",
    "import yfinance as yf\n",
    "import pandas_datareader.data as pdr\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "from numpy import array\n",
    "\n",
    "\n",
    "df = data = pd.read_csv(\"https://raw.githubusercontent.com/Mizanur55/Data/main/S%26P500%20jan1990-jan2021%20%20OHLC%20-%20without%20index.csv\")\n",
    "df"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 141,
   "metadata": {},
   "outputs": [],
   "source": [
    "\n",
    "# split a multivariate sequence into samples\n",
    "def split_sequences(sequences, n_steps):\n",
    "    X, y = list(), list()\n",
    "    for i in range(len(sequences)):\n",
    "        # find the end of this pattern\n",
    "        end_ix = i + n_steps\n",
    "        # check if we are beyond the dataset\n",
    "        if end_ix > len(sequences):\n",
    "            break\n",
    "        # gather input and output parts of the pattern\n",
    "        seq_x, seq_y = sequences[i:end_ix, :-1], sequences[end_ix-1, -1]\n",
    "        X.append(seq_x)\n",
    "        y.append(seq_y)\n",
    "    return array(X), array(y)\n",
    "\n",
    "df1 = df[['Open','High','Low','Adj Close']]\n",
    "\n",
    "# normalizing the dataframe. values are now between [0,1]\n",
    "# https://stackoverflow.com/questions/26414913/normalize-columns-of-pandas-data-frame\n",
    "\n",
    "# df1 = (df1-df1.min())/(df1.max()-df1.min())\n",
    "\n",
    "\n",
    "# gettting all the colums as arrays\n",
    "open_col = array(df1['Open'])\n",
    "high_col = array(df1['High'])\n",
    "low_col = array(df1['Low'])\n",
    "adj_close_col = array(df1['Adj Close'])\n",
    "# reshaping the columns\n",
    "open_col = open_col.reshape(len(open_col),1)\n",
    "high_col = high_col.reshape(len(high_col),1)\n",
    "low_col = low_col.reshape(len(low_col),1)\n",
    "adj_close_col = adj_close_col.reshape(len(adj_close_col),1)\n",
    "# horizontal staking\n",
    "dataset = np.hstack((high_col, low_col,adj_close_col))\n",
    "n_steps = 3\n",
    "#  X and y have full data - miz\n",
    "X, y = split_sequences(dataset, n_steps)\n",
    "# for i in range(len(X)):\n",
    "#     print(X[i], y[i])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 142,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "(830, 3, 2)\n",
      "(1, 3, 2)\n",
      "Build finished in 0:00:00                                                      \n",
      "Optimization finished in 0:00:00                                               \n",
      "|             Constructing graph: build stage (0%)             | ETA:  --:--:--"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "C:\\Users\\mizan\\anaconda3\\lib\\site-packages\\nengo_dl\\simulator.py:461: UserWarning: No GPU support detected. See https://www.nengo.ai/nengo-dl/installation.html#installing-tensorflow for instructions on setting up TensorFlow with GPU support.\n",
      "  \"No GPU support detected. See \"\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Construction finished in 0:00:00                                               \n",
      "Epoch 1/10\n",
      "830/830 [==============================] - 10s 9ms/step - loss: 1152515.3750 - probe_loss: 1152515.3750\n",
      "Epoch 2/10\n",
      "830/830 [==============================] - 7s 9ms/step - loss: 517001.0625 - probe_loss: 517001.0625\n",
      "Epoch 3/10\n",
      "830/830 [==============================] - 7s 9ms/step - loss: 192954.3906 - probe_loss: 192954.3906\n",
      "Epoch 4/10\n",
      "830/830 [==============================] - 7s 8ms/step - loss: 59259.9727 - probe_loss: 59259.9727\n",
      "Epoch 5/10\n",
      "830/830 [==============================] - 7s 8ms/step - loss: 21344.4512 - probe_loss: 21344.4512\n",
      "Epoch 6/10\n",
      "830/830 [==============================] - 8s 9ms/step - loss: 15410.5732 - probe_loss: 15410.5732\n",
      "Epoch 7/10\n",
      "830/830 [==============================] - 7s 9ms/step - loss: 15077.1152 - probe_loss: 15077.1152\n",
      "Epoch 8/10\n",
      "830/830 [==============================] - 8s 9ms/step - loss: 15084.2217 - probe_loss: 15084.2217\n",
      "Epoch 9/10\n",
      "830/830 [==============================] - 7s 9ms/step - loss: 15094.9336 - probe_loss: 15094.9336\n",
      "Epoch 10/10\n",
      "830/830 [==============================] - 7s 9ms/step - loss: 15103.1133 - probe_loss: 15103.1133\n",
      "{<Probe at 0x1b94aeb2bc8 of 'output' of <Node (unlabeled) at 0x1b94aeb24c8>>: array([[[1267.3568]]], dtype=float32)}\n",
      "{<Probe at 0x1b94aeb2bc8 of 'output' of <Node (unlabeled) at 0x1b94aeb24c8>>: array([[[1267.3517]]], dtype=float32)}\n",
      "{<Probe at 0x1b94aeb2bc8 of 'output' of <Node (unlabeled) at 0x1b94aeb24c8>>: array([[[1267.3567]]], dtype=float32)}\n",
      "{<Probe at 0x1b94aeb2bc8 of 'output' of <Node (unlabeled) at 0x1b94aeb24c8>>: array([[[1267.3568]]], dtype=float32)}\n"
     ]
    }
   ],
   "source": [
    "import nengo\n",
    "import tensorflow as tf\n",
    "import numpy as np\n",
    "import nengo_dl\n",
    "import matplotlib.pyplot as plt\n",
    "from numpy import array\n",
    "\n",
    "n_steps = 3\n",
    "x_train = X[5000:5830]\n",
    "\n",
    "print(x_train.shape)\n",
    "n_features = x_train.shape[2]\n",
    "\n",
    "\n",
    "y_train = y[5000:5830]\n",
    "#  convering y_train to 3D array\n",
    "list_of_y = []\n",
    "for i in y_train:\n",
    "    list_of_y.append([[i]])\n",
    "    \n",
    "y_train = np.array(list_of_y)\n",
    "\n",
    "\n",
    "x_test = X[5900:5901]\n",
    "y_test = y[5900:5901]\n",
    "\n",
    "print(x_test.shape)\n",
    "\n",
    "with nengo.Network() as net:\n",
    "    # remove some unnecessary features to speed up the training\n",
    "    nengo_dl.configure_settings(\n",
    "        trainable=None,\n",
    "        stateful=None,\n",
    "        keep_history=False,\n",
    "    )\n",
    "\n",
    "    inp = nengo.Node((np.zeros(x_train.shape[-1])))\n",
    "    # lmu cell\n",
    "#      chose these values because they give the best results\n",
    "    lmu = LMUCell(\n",
    "        units=516,\n",
    "        order=516,\n",
    "        theta=x_train.shape[1],\n",
    "        input_d=x_train.shape[-1],\n",
    "    )\n",
    "    \n",
    "\n",
    "    conn = nengo.Connection(inp, lmu.x, synapse=None)\n",
    "    net.config[conn].trainable = False    \n",
    "    \n",
    "    \n",
    " \n",
    "    # dense linear readout \n",
    "    out = nengo.Node(size_in=1) #changed to 1\n",
    "    nengo.Connection(lmu.h, out,transform=nengo_dl.dists.Glorot(), synapse=None)\n",
    "   \n",
    "    p = nengo.Probe(out)   \n",
    "\n",
    "    \n",
    "with nengo_dl.Simulator(net) as sim:\n",
    "    sim.compile(\n",
    "        loss=tf.losses.mse,\n",
    "        optimizer=tf.optimizers.Adam(),\n",
    "#         metrics=[\"mse\"],\n",
    "    )\n",
    "#  I kept the epoch to 10 since the loss does not go down much after that.\n",
    "    sim.fit(x_train, y_train, epochs=10)\n",
    "#     sim.save_params(\"./lmu_params\")\n",
    "    print(sim.predict(x_test))\n",
    "#     lets print out some different samples to check the output for them\n",
    "    print(sim.predict(array([X[50]])))\n",
    "    print(sim.predict(array([X[1000]])))\n",
    "    print(sim.predict(array([X[2000]])))\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
